package com.ruoyi.nanjing.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.nanjing.mapper.TBdSubstationMapper;
import com.ruoyi.nanjing.domain.TBdSubstation;
import com.ruoyi.nanjing.service.ITBdSubstationService;
import com.ruoyi.common.core.text.Convert;

/**
 * 工位管理Service业务层处理
 * 
 * @author limy
 * @date 2021-01-22
 */
@Service
public class TBdSubstationServiceImpl implements ITBdSubstationService 
{
    @Autowired
    private TBdSubstationMapper tBdSubstationMapper;

    /**
     * 查询工位管理
     * 
     * @param ID 工位管理ID
     * @return 工位管理
     */
    @Override
    public TBdSubstation selectTBdSubstationById(Long ID)
    {
        return tBdSubstationMapper.selectTBdSubstationById(ID);
    }

    /**
     * 查询工位管理列表
     * 
     * @param tBdSubstation 工位管理
     * @return 工位管理
     */
    @Override
    public List<TBdSubstation> selectTBdSubstationList(TBdSubstation tBdSubstation)
    {
        return tBdSubstationMapper.selectTBdSubstationList(tBdSubstation);
    }

    /**
     * 新增工位管理
     * 
     * @param tBdSubstation 工位管理
     * @return 结果
     */
    @Override
    public int insertTBdSubstation(TBdSubstation tBdSubstation)
    {
        return tBdSubstationMapper.insertTBdSubstation(tBdSubstation);
    }

    /**
     * 修改工位管理
     * 
     * @param tBdSubstation 工位管理
     * @return 结果
     */
    @Override
    public int updateTBdSubstation(TBdSubstation tBdSubstation)
    {
        return tBdSubstationMapper.updateTBdSubstation(tBdSubstation);
    }

    /**
     * 删除工位管理对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTBdSubstationByIds(String ids)
    {
        return tBdSubstationMapper.deleteTBdSubstationByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除工位管理信息
     * 
     * @param ID 工位管理ID
     * @return 结果
     */
    @Override
    public int deleteTBdSubstationById(Long ID)
    {
        return tBdSubstationMapper.deleteTBdSubstationById(ID);
    }
}
